<?php 
/*
	Plugin Name: Show Support Ribbon
	Plugin URI: https://perishablepress.com/show-support-ribbon/
	Description: Displays a customizable "show support" ribbon, banner, or badge on your site.
	Tags: badge, banner, button, ribbon, support,  charity, event, fundraiser, link, non-profit, organization, rally
	Author: Jeff Starr
	Author URI: https://plugin-planet.com/
	Donate link: https://m0n.co/donate
	Contributors: specialk
	Requires at least: 4.1
	Tested up to: 4.9
	Stable tag: 20171103
	Version: 20171103
	Requires PHP: 5.2
	Text Domain: show-support-ribbon
	Domain Path: /languages
	License: GPL v2 or later
*/

/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 
	2 of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	with this program. If not, visit: https://www.gnu.org/licenses/
	
	Copyright 2017 Monzilla Media. All rights reserved.
*/

if (!defined('ABSPATH')) die();

$ssr_wp_vers = '4.1';
$ssr_version = '20171103';
$ssr_plugin  = esc_html__('Show Support Ribbon', 'show-support-ribbon');
$ssr_options = get_option('ssr_options');
$ssr_path    = plugin_basename(__FILE__); // 'show-support-ribbon/show-support-ribbon.php';
$ssr_homeurl = 'https://perishablepress.com/show-support-ribbon/';

function ssr_i18n_init() {
	load_plugin_textdomain('show-support-ribbon', false, dirname(plugin_basename(__FILE__)) . '/languages/');
}
add_action('plugins_loaded', 'ssr_i18n_init');

function ssr_require_wp_version() {
	global $ssr_path, $ssr_plugin, $ssr_wp_vers;
	if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
		$wp_version = get_bloginfo('version');
		if (version_compare($wp_version, $ssr_wp_vers, '<')) {
			if (is_plugin_active($ssr_path)) {
				deactivate_plugins($ssr_path);
				$msg =  '<strong>' . $ssr_plugin . '</strong> ' . esc_html__('requires WordPress ', 'show-support-ribbon') . $ssr_wp_vers . esc_html__(' or higher, and has been deactivated!', 'show-support-ribbon') . '<br />';
				$msg .= esc_html__('Please return to the', 'show-support-ribbon') . ' <a href="' . admin_url() . '">' . esc_html__('WordPress Admin area', 'show-support-ribbon') . '</a> ' . esc_html__('to upgrade WordPress and try again.', 'show-support-ribbon');
				wp_die($msg);
			}
		}
	}
}
add_action('admin_init', 'ssr_require_wp_version');

function ssr_display_ribbon() { 
	global $ssr_options;

	$style  = $ssr_options['ssr_style'];
	$enable = $ssr_options['ssr_enable'];
	$href   = $ssr_options['ssr_href'];
	$title  = $ssr_options['ssr_title'];
	$link   = $ssr_options['ssr_link'];
	$blank  = $ssr_options['ssr_blank'];

	if ($enable == true) {
		if ($style == 'ssr_badge') {
			$css_div  = 'position:fixed;right:5px;top:5px;z-index:999999;';
			$css_link = 'display:block;width:88px;height:88px;color:#fff;background:rgba(102,153,204,0.7);font-size:11px;text-align:center;line-height:88px;text-decoration:none;font-weight:bold;border:2px solid #efefef;-webkit-border-radius:99px;-moz-border-radius:99px;border-radius:99px;-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);-moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);';

		} elseif ($style == 'ssr_banner') {
			$css_div  = 'position:fixed;right:-2px;top:5px;z-index:999999;';
			$css_link = 'display:block;width:120px;height:40px;color:rgba(51,102,153,0.9);background:rgba(255,255,255,0.7);font-size:12px; text-align:center; line-height:40px; text-decoration:none; font-weight:bold;border:1px solid rgba(102,153,204,0.7);-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);-moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);';

		} elseif ($style == 'ssr_ribbon') {
			$css_div = 'position:fixed;right:-60px;top:20px;z-index:999999;';
			$css_link = 'display:block;width:200px;height:30px;color:#fff;background:rgba(102,153,204,0.9);font-size:12px;line-height:30px;text-align:center;text-decoration:none; border:1px solid rgba(255,255,255,0.7);-webkit-transform:rotate(40deg);-moz-transform:rotate(40deg);-ms-transform:rotate(40deg);-o-transform:rotate(40deg);-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);-moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);';

		} elseif ($style == 'ssr_link') {
			$css_div = 'position:fixed; right:5px; top:5px; z-index:999999;';
			$css_link = 'font-size:12px;';

		} elseif ($style == 'ssr_custom') {
			$css_div  = $ssr_options['ssr_outer'];
			$css_link = $ssr_options['ssr_inner'];
		}
		if ($blank == true) {
			return "\n" . '<div id="show-support-ribbon" style="' . $css_div . '"><a href="' . $href . '" title="' . $title . '" style="' . $css_link . '" target="_blank">' . $link . '</a><div>' . "\n\n";
		} else {
			return "\n" . '<div id="show-support-ribbon" style="' . $css_div . '"><a href="' . $href . '" title="' . $title . '" style="' . $css_link . '">' . $link . '</a><div>' . "\n\n";
		}
	}
}

function ssr_enable_display_ribbon() {
	echo ssr_display_ribbon();
}
add_action('wp_footer', 'ssr_enable_display_ribbon');

function ssr_shortcode() {
	return ssr_display_ribbon();
}
add_shortcode('show_support_ribbon','ssr_shortcode');

function show_support_ribbon() {
	echo ssr_display_ribbon();
}

function ssr_plugin_action_links($links, $file) {
	global $ssr_path;
	if ($file == $ssr_path) {
		$ssr_links = '<a href="' . get_admin_url() . 'options-general.php?page=' . $ssr_path . '">' . esc_html__('Settings', 'show-support-ribbon') .'</a>';
		array_unshift($links, $ssr_links);
	}
	return $links;
}
add_filter ('plugin_action_links', 'ssr_plugin_action_links', 10, 2);

function add_ssr_links($links, $file) {
		if ($file == plugin_basename(__FILE__)) {
		
		$href  = 'https://wordpress.org/support/plugin/show-support-ribbon/reviews/?rate=5#new-post';
		$title = esc_html__('Give us a 5-star rating at WordPress.org', 'show-support-ribbon');
		$text  = esc_html__('Rate this plugin', 'show-support-ribbon') .'&nbsp;&raquo;';
		
		$links[] = '<a target="_blank" href="'. $href .'" title="'. $title .'">'. $text .'</a>';
		
	}
	return $links;
}
add_filter('plugin_row_meta', 'add_ssr_links', 10, 2);

function ssr_delete_plugin_options() {
	delete_option('ssr_options');
}
if ($ssr_options['default_options'] == 1) {
	register_uninstall_hook (__FILE__, 'ssr_delete_plugin_options');
}

function ssr_add_defaults() {
	$tmp = get_option('ssr_options');
	if(($tmp['default_options'] == '1') || (!is_array($tmp))) {
		$arr = array(
			'default_options' => 0,
			'ssr_enable'      => 0,
			'ssr_style'       => 'ssr_ribbon',
			'ssr_outer'       => 'position:fixed;right:-60px;top:20px;z-index:9999;',
			'ssr_inner'       => 'display:block;width:200px;height:30px;color:#fff;background:rgba(102,153,204,0.9);font-size:12px;line-height:30px;text-align:center;text-decoration:none; border:1px solid rgba(255,255,255,0.7);-webkit-transform:rotate(40deg);-moz-transform:rotate(40deg);-ms-transform:rotate(40deg);-o-transform:rotate(40deg);-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);-moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);',
			'ssr_href'        => 'http://example.com/',
			'ssr_title'       => 'Your event here!',
			'ssr_link'        => 'Show Support!',
			'ssr_blank'       => 1,
		);
		update_option('ssr_options', $arr);
	}
}
register_activation_hook (__FILE__, 'ssr_add_defaults');

$ssr_display_styles = array(
	'ssr_badge'  => array(
		'value' => 'ssr_badge',
		'label' => 'Badge'
	),
	'ssr_banner' => array(
		'value' => 'ssr_banner',
		'label' => 'Banner'
	),
	'ssr_ribbon' => array(
		'value' => 'ssr_ribbon',
		'label' => 'Ribbon'
	),
	'ssr_link'   => array(
		'value' => 'ssr_link',
		'label' => 'Link'
	),
	'ssr_custom' => array(
		'value' => 'ssr_custom',
		'label' => 'Custom'
	)
);

function ssr_init() {
	register_setting('ssr_plugin_options', 'ssr_options', 'ssr_validate_options');
}
add_action ('admin_init', 'ssr_init');

function ssr_validate_options($input) {
	
	global $ssr_display_styles;

	if (!isset($input['default_options'])) $input['default_options'] = null;
	$input['default_options'] = ($input['default_options'] == 1 ? 1 : 0);

	if (!isset($input['ssr_enable'])) $input['ssr_enable'] = null;
	$input['ssr_enable'] = ($input['ssr_enable'] == '1' ? '1' : '0');

	if (!isset($input['ssr_blank'])) $input['ssr_blank'] = null;
	$input['ssr_blank'] = ($input['ssr_blank'] == '1' ? '1' : '0');

	if (!isset($input['ssr_style'])) $input['ssr_style'] = null;
	if (!array_key_exists($input['ssr_style'], $ssr_display_styles)) $input['ssr_style'] = null;

	$input['ssr_outer'] = sanitize_text_field($input['ssr_outer']);
	$input['ssr_inner'] = sanitize_text_field($input['ssr_inner']);
	$input['ssr_href']  = esc_attr($input['ssr_href']);
	$input['ssr_title'] = esc_attr($input['ssr_title']);
	$input['ssr_link']  = esc_attr($input['ssr_link']);

	return $input;
}

function ssr_add_options_page() {
	global $ssr_plugin;
	add_options_page($ssr_plugin, esc_html__('Support Ribbon', 'show-support-ribbon'), 'manage_options', __FILE__, 'ssr_render_form');
}
add_action ('admin_menu', 'ssr_add_options_page');

function ssr_render_form() {
	global $ssr_plugin, $ssr_options, $ssr_path, $ssr_homeurl, $ssr_version, $ssr_display_styles; ?>

	<style type="text/css">
		.mm-panel-overview {
			padding: 0 15px 15px 175px;
			background: url(<?php echo plugins_url(); ?>/show-support-ribbon/ssr-logo.png);
			background-repeat: no-repeat; background-position: 15px 0; background-size: 160px 121px;
			}
		#mm-plugin-options h1 small { line-height: 12px; font-size: 12px; color: #bbb; }
		#mm-plugin-options h2 { margin: 0; padding: 12px 0 12px 15px; font-size: 16px; cursor: pointer; }
		#mm-plugin-options h3 { margin: 20px 15px; font-size: 14px; }
		
		#mm-plugin-options p { margin-left: 15px; }
		#mm-plugin-options ul { margin-left: 40px; margin-bottom: 15px; }
		#mm-plugin-options li { margin: 8px 0; list-style-type: disc; }
		#mm-plugin-options abbr { cursor: help; border-bottom: 1px dotted #dfdfdf; }
		#mm-plugin-options pre { padding: 10px 5px; line-height: 18px; font-size: 12px; }
		
		.mm-table-wrap { margin: 15px; }
		.mm-table-wrap td { padding: 5px 10px; vertical-align: middle; }
		.mm-table-wrap .widefat th { width: 20%; padding: 10px 15px; vertical-align: middle; }
		.mm-table-wrap .widefat td { width: 80%; padding: 10px; vertical-align: middle; }

		.mm-item-caption { margin: 1px 0 0 3px; font-size: 11px; color: #777; }
		.mm-item-caption code { font-size: 11px; }
		.mm-code-example { margin: 10px 0 20px 0; }
		.mm-code-example div { margin: 0 0 15px 15px; }
		.mm-code-example code { padding: 5px; background-color: #fafae0; color: #555; font-size: 14px; }
		.mm-radio-inputs { margin: 5px 0; }

		#setting-error-settings_updated { margin: 8px 0 15px 0; }
		#setting-error-settings_updated p { margin: 7px 0; }
		#mm-plugin-options .button-primary { margin: 0 0 15px 15px; }

		#mm-panel-tertiary pre { margin: 10px 0 20px 30px; }
		#mm-panel-tertiary hr { width: 97%; margin: 25px auto; }
		.mm-example-heading { margin-left: 15px; }
		.mm-example-heading code { font-size: 13px; }

		.mm-custom-style { background-color: #efefef; }
		.mm-custom-style pre { margin: 10px 0 0 0; text-shadow: 1px 1px 1px rgba(255,255,255,0.5); }
		.mm-custom-style label code { font-size: 13px; }
		#mm-panel-toggle { margin: 5px 0; }
		#mm-credit-info { margin-top: -5px; }
	</style>

	<div id="mm-plugin-options" class="wrap">
		<h1><?php echo $ssr_plugin; ?> <small><?php echo 'v' . $ssr_version; ?></small></h1>
		<div id="mm-panel-toggle"><a href="<?php get_admin_url() . 'options-general.php?page=' . $ssr_path; ?>"><?php esc_html_e('Toggle all panels', 'show-support-ribbon'); ?></a></div>

		<form method="post" action="options.php">
			<?php $ssr_options = get_option('ssr_options'); settings_fields('ssr_plugin_options'); ?>

			<div class="metabox-holder">
				<div class="meta-box-sortables ui-sortable">
					
					<div id="mm-panel-overview" class="postbox">
						<h2><?php esc_html_e('Overview', 'show-support-ribbon'); ?></h2>
						<div class="toggle<?php if (isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<div class="mm-panel-overview">
								<p>
									<strong><?php echo $ssr_plugin; ?></strong> <?php esc_html_e('(SSR) displays a custom support ribbon on your site. SSR includes four built-in display styles: badge, banner, ribbon, or link.', 'show-support-ribbon'); ?>
									<?php esc_html_e('SSR also includes the option to use your own custom CSS to style the ribbon and position it anywhere on the page. See the "Customization Tips" panel for more information.', 'show-support-ribbon'); ?>
									<?php esc_html_e('Optionally you may use the shortcode to display the ribbon on any post or page, or use the template tag to display the ribbon anywhere in your theme template.', 'show-support-ribbon'); ?>
								</p>
								<ul>
									<li><a id="mm-panel-primary-link" href="#mm-panel-primary"><?php esc_html_e('Plugin Settings', 'show-support-ribbon'); ?></a></li>
									<li><a id="mm-panel-secondary-link" href="#mm-panel-secondary"><?php esc_html_e('Shortcodes &amp; Template Tags', 'show-support-ribbon'); ?></a></li>
									<li><a id="mm-panel-tertiary-link" href="#mm-panel-tertiary"><?php esc_html_e('Customization Tips', 'show-support-ribbon'); ?></a></li>
									<li><a target="_blank" href="https://wordpress.org/plugins/show-support-ribbon/"><?php esc_html_e('Plugin Homepage', 'show-support-ribbon'); ?></a></li>
								</ul>
								<p>
									<?php esc_html_e('If you like this plugin, please', 'show-support-ribbon'); ?> 
									<a target="_blank" href="https://wordpress.org/support/plugin/show-support-ribbon/reviews/?rate=5#new-post" title="<?php esc_attr_e('THANK YOU for your support!', 'show-support-ribbon'); ?>"><?php esc_html_e('give it a 5-star rating', 'show-support-ribbon'); ?>&nbsp;&raquo;</a>
								</p>
							</div>
						</div>
					</div>
					
					<div id="mm-panel-primary" class="postbox">
						<h2><?php esc_html_e('Plugin Settings', 'show-support-ribbon'); ?></h2>
						<div class="toggle<?php if (!isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<p><?php esc_html_e('Here you may enable and configure the plugin. Note: select the "Custom" style to reveal more options.', 'show-support-ribbon'); ?></p>
							<div class="mm-table-wrap">
								<table class="widefat mm-table">
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_enable]"><?php esc_html_e('Display the ribbon?', 'show-support-ribbon'); ?></label></th>
										<td><input type="checkbox" name="ssr_options[ssr_enable]" value="1" <?php if (isset($ssr_options['ssr_enable'])) { checked('1', $ssr_options['ssr_enable']); } ?> /> 
										<?php esc_html_e('Check the box to display the ribbon on your site.', 'show-support-ribbon'); ?></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_blank]"><?php esc_html_e('Open ribbon link in new tab?', 'show-support-ribbon'); ?></label></th>
										<td><input type="checkbox" name="ssr_options[ssr_blank]" value="1" <?php if (isset($ssr_options['ssr_blank'])) { checked('1', $ssr_options['ssr_blank']); } ?> /> 
										<?php esc_html_e('Check the box to open the ribbon link in a new tab. Or, leave unchecked to open in same tab.', 'show-support-ribbon'); ?></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_style]"><?php esc_html_e('Select your style', 'show-support-ribbon'); ?></label></th>
										<td>
											<?php if (!isset($checked)) $checked = '';
												foreach ($ssr_display_styles as $ssr_display_style) {
													$radio_setting = $ssr_options['ssr_style'];
													if ('' != $radio_setting) {
														if ($ssr_options['ssr_style'] == $ssr_display_style['value']) {
															$checked = "checked=\"checked\"";
														} else {
															$checked = '';
														}
													} ?>
													<div class="mm-radio-inputs">
														<input type="radio" name="ssr_options[ssr_style]" value="<?php echo esc_attr($ssr_display_style['value']); ?>" <?php echo $checked; ?> /> 
														<?php echo $ssr_display_style['label']; ?>
													</div>
											<?php } ?>
										</td>
									</tr>
									<tr class="mm-custom-style">
										<th scope="row"><label class="description"><?php esc_html_e('HTML', 'show-support-ribbon'); ?></label></th>
										<td>
											<div><?php esc_html_e('FYI: here is the markup that is used to create the ribbon:', 'show-support-ribbon'); ?></div>
<pre>&lt;div id="show-support-ribbon" style="{CSS for &lt;div&gt;}"&gt;
	&lt;a target="_blank" href="{URL}" title="{title}" style="{CSS for &lt;a&gt;}"&gt;{link}&lt;/a&gt;
&lt;/div&gt;</pre>
										</td>
									</tr>
									<tr class="mm-custom-style">
										<th scope="row"><label class="description" for="ssr_options[ssr_outer]"><?php esc_html_e('CSS for', 'show-support-ribbon'); ?> <code>&lt;div&gt;</code></label></th>
										<td><textarea class="textarea large-text code" rows="7" cols="55" name="ssr_options[ssr_outer]"><?php echo esc_textarea($ssr_options['ssr_outer']); ?></textarea>
										<div class="mm-item-caption"><?php esc_html_e('Custom CSS for the', 'show-support-ribbon'); ?> <code>&lt;div&gt;</code> <?php esc_html_e('tag', 'show-support-ribbon'); ?></div></td>
									</tr>
									<tr class="mm-custom-style">
										<th scope="row"><label class="description" for="ssr_options[ssr_inner]"><?php esc_html_e('CSS for', 'show-support-ribbon'); ?> <code>&lt;a&gt;</code></label></th>
										<td><textarea class="textarea large-text code" rows="7" cols="55" name="ssr_options[ssr_inner]"><?php echo esc_textarea($ssr_options['ssr_inner']); ?></textarea>
										<div class="mm-item-caption"><?php esc_html_e('Custom CSS for the', 'show-support-ribbon'); ?> <code>&lt;a&gt;</code> <?php esc_html_e('tag', 'show-support-ribbon'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_href]"><?php esc_html_e('Link URL', 'show-support-ribbon'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="ssr_options[ssr_href]" value="<?php echo $ssr_options['ssr_href']; ?>" />
										<div class="mm-item-caption"><?php esc_html_e('Enter the URL that should be used for the ribbon link', 'show-support-ribbon'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_title]"><?php esc_html_e('Link title', 'show-support-ribbon'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="ssr_options[ssr_title]" value="<?php echo $ssr_options['ssr_title']; ?>" />
										<div class="mm-item-caption"><?php esc_html_e('Enter the title that should be used for the ribbon link', 'show-support-ribbon'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="ssr_options[ssr_link]"><?php esc_html_e('Link text', 'show-support-ribbon'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="ssr_options[ssr_link]" value="<?php echo $ssr_options['ssr_link']; ?>" />
										<div class="mm-item-caption"><?php esc_html_e('Enter the anchor text that should be used for the ribbon link', 'show-support-ribbon'); ?></div></td>
									</tr>
								</table>
							</div>
							<input type="submit" class="button-primary" value="<?php esc_attr_e('Save Settings', 'show-support-ribbon'); ?>" />
						</div>
					</div>
					
					<div id="mm-panel-secondary" class="postbox">
						<h2><?php esc_html_e('Shortcode &amp; Template Tag', 'show-support-ribbon'); ?></h2>
						<div class="toggle default-hidden">
							<div class="mm-code-example">
								<h3><?php esc_html_e('Shortcode', 'show-support-ribbon'); ?></h3>
								<div><?php esc_html_e('Display the ribbon on any post or page:', 'show-support-ribbon'); ?></div>
								<div><code>[show_support_ribbon]</code></div>

								<h3><?php esc_html_e('Template tag', 'show-support-ribbon'); ?></h3>
								<div><?php esc_html_e('Display the ribbon anywhere in your theme:', 'show-support-ribbon'); ?></div>
								<div><code>&lt;?php if (function_exists('show_support_ribbon')) show_support_ribbon(); ?&gt;</code></div>
							</div>
						</div>
					</div>
					
					<div id="mm-panel-tertiary" class="postbox">
						<h2><?php esc_html_e('Customization Tips', 'show-support-ribbon'); ?></h2>
						<div class="toggle default-hidden">
							<p><?php esc_html_e('For those new to styling HTML with CSS, here are some recipes and tips.', 'show-support-ribbon'); ?></p>
							<ul>
								<li><strong>Location</strong> &mdash; For the <code>&lt;div&gt;</code>, use <code>position:fixed;</code> and then specify the location with something like <code>right:0; bottom:5px;</code>.</li>
								<li><strong>Structural styles</strong> &mdash; Apply structural styles such as <code>margin</code>, <code>width</code>, and <code>height</code> to the <em>block-level</em> element, <code>&lt;div&gt;</code>.</li>
								<li><strong>Aesthetic styles</strong> &mdash; Apply aesthetic styles such as <code>padding</code>, <code>color</code>, and <code>font-family</code> to the <em>inline-level</em> element, <code>&lt;a&gt;</code>.</li>
								<li><strong>Recipes</strong> &mdash; Using the recipes below as Custom CSS, you can change the position, size, and color of the ribbon. And much more if you get creative ;)</li>
							</ul>
							<hr />
							<div class="mm-example-heading"><strong>Badge</strong> <code>&lt;div&gt;</code></div>
							<ul>
								<li>Display top left: <code>position:fixed; left:5px; top:5px; z-index:9999;</code></li>
								<li>Display top right: <code>position:fixed; right:5px; top:5px; z-index:9999;</code></li>
								<li>Display bottom left: <code>position:fixed; left:5px; bottom:5px; z-index:9999;</code></li>
								<li>Display bottom right: <code>position:fixed; right:5px; bottom:5px; z-index:9999;</code></li>
							</ul>
							<div class="mm-example-heading"><strong>Badge</strong> <code>&lt;a&gt;</code></div>
<pre>display:block; width:88px; height:88px; color:#fff; background:rgba(102,153,204,0.7); 
font-size:11px; text-align:center; line-height:88px; text-decoration:none; font-weight:bold; 
border:2px solid #efefef;
-webkit-border-radius:99px; 
   -moz-border-radius:99px; 
        border-radius:99px;
-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
   -moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
        box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);</pre>
							<hr />
							<div class="mm-example-heading"><strong>Banner</strong> <code>&lt;div&gt;</code></div>
							<ul>
								<li>Display top left: <code>position:fixed; left:-2px; top:5px; z-index:9999;</code></li>
								<li>Display top right: <code>position:fixed; right:-2px; top:5px; z-index:9999;</code></li>
								<li>Display bottom left: <code>position:fixed; left:-2px; bottom:5px; z-index:9999;</code></li>
								<li>Display bottom right: <code>position:fixed; right:-2px; bottom:5px; z-index:9999;</code></li>
							</ul>
							<div class="mm-example-heading"><strong>Banner</strong> <code>&lt;a&gt;</code></div>
<pre>display:block; width:120px; height:40px; color:rgba(51,102,153,0.9); background:rgba(255,255,255,0.7); 
font-size:12px; text-align:center; line-height:40px; text-decoration:none; font-weight:bold;
border:1px solid rgba(102,153,204,0.7); 
-webkit-border-radius:3px; 
   -moz-border-radius:3px; 
        border-radius:3px;
-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
   -moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
        box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);</pre>
							<hr />
							<div class="mm-example-heading"><strong>Ribbon</strong> <code>&lt;div&gt;</code></div>
							<ul>
								<li>Display top left: <code>position:fixed; left:-60px; top:20px; z-index:9999;</code></li>
								<li>Display top right: <code>position:fixed; right:-60px; top:20px; z-index:9999;</code></li>
								<li>Display bottom left: <code>position:fixed; left:-60px; bottom:20px; z-index:9999;</code></li>
								<li>Display bottom right: <code>position:fixed; right:-60px; bottom:20px; z-index:9999;</code></li>
							</ul>
							<div class="mm-example-heading"><strong>Ribbon</strong> <code>&lt;a&gt;</code> (top left)</div>
<pre>display:block; width:200px; height:30px; color:#fff; background:rgba(102,153,204,0.9); 
font-size:12px; line-height:30px; text-align:center; text-decoration:none; 
border:1px solid rgba(255,255,255,0.7);
-webkit-transform:rotate(-40deg); 
   -moz-transform:rotate(-40deg); 
    -ms-transform:rotate(-40deg); 
     -o-transform:rotate(-40deg);</pre>
							<div class="mm-example-heading"><strong>Ribbon</strong> <code>&lt;a&gt;</code> (top right)</div>
<pre>display:block; width:200px; height:30px; color:#fff; background:rgba(102,153,204,0.9); 
font-size:12px; line-height:30px; text-align:center; text-decoration:none; 
border:1px solid rgba(255,255,255,0.7);
-webkit-transform:rotate(40deg); 
   -moz-transform:rotate(40deg); 
    -ms-transform:rotate(40deg); 
     -o-transform:rotate(40deg);</pre>
							<div class="mm-example-heading"><strong>Ribbon</strong> <code>&lt;a&gt;</code> (bottom left)</div>
<pre>display:block; width:200px; height:30px; color:#fff; background:rgba(102,153,204,0.9); 
font-size:12px; line-height:30px; text-align:center; text-decoration:none; 
border:1px solid rgba(255,255,255,0.7);
-webkit-transform:rotate(40deg); 
   -moz-transform:rotate(40deg); 
    -ms-transform:rotate(40deg); 
     -o-transform:rotate(40deg);</pre>
							<div class="mm-example-heading"><strong>Ribbon</strong> <code>&lt;a&gt;</code> (bottom right)</div>
<pre>display:block; width:200px; height:30px; color:#fff; background:rgba(102,153,204,0.9); 
font-size:12px; line-height:30px; text-align:center; text-decoration:none; 
border:1px solid rgba(255,255,255,0.7);
-webkit-transform:rotate(-40deg); 
   -moz-transform:rotate(-40deg); 
    -ms-transform:rotate(-40deg); 
     -o-transform:rotate(-40deg);</pre>
							<div class="mm-example-heading">Note: to add a drop shadow, add the following CSS to the <code>&lt;a&gt;</code> tag</div>
<pre>-webkit-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
   -moz-box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3); 
        box-shadow:1px 1px 3px 0 rgba(0,0,0,0.3);</pre>
							<div class="mm-example-heading">Note: to hide the ribbon on small screens, add the following CSS for the <code>&lt;div&gt;</code> tag</div>
<pre>/* adjust the 500px to whatever width is desired */
@media (max-width: 500px) {
	#show-support-ribbon { display: none; }
}</pre>
							<hr />
							<div class="mm-example-heading"><strong>Link</strong> <code>&lt;div&gt;</code></div>
							<ul>
								<li>Display top left: <code>position:fixed; left:5px; top:5px; z-index:9999;</code></li>
								<li>Display top right: <code>position:fixed; right:5px; top:5px; z-index:9999;</code></li>
								<li>Display bottom left: <code>position:fixed; left:5px; bottom:5px; z-index:9999;</code></li>
								<li>Display bottom right: <code>position:fixed; right:5px; bottom:5px; z-index:9999;</code></li>
							</ul>
							<div class="mm-example-heading"><strong>Link</strong> <code>&lt;a&gt;</code></div>
							<pre>font-size:12px;</pre>
						</div>
					</div>
					
					<div id="mm-restore-settings" class="postbox">
						<h2><?php esc_html_e('Restore Defaults', 'show-support-ribbon'); ?></h2>
						<div class="toggle<?php if (!isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<p>
								<input name="ssr_options[default_options]" type="checkbox" value="1" id="mm_restore_defaults" <?php if (isset($ssr_options['default_options'])) { checked('1', $ssr_options['default_options']); } ?> /> 
								<label class="description" for="ssr_options[default_options]"><?php esc_html_e('Restore default options upon plugin deactivation/reactivation.', 'show-support-ribbon'); ?></label>
							</p>
							<p>
								<small>
									<strong><?php esc_html_e('Tip:', 'show-support-ribbon'); ?></strong> 
									<?php esc_html_e('leave this option unchecked to remember your settings. Or, to go ahead and restore all default options, check the box, save your settings, and then deactivate/reactivate the plugin.', 'show-support-ribbon'); ?>
								</small>
							</p>
							<input type="submit" class="button-primary" value="<?php esc_attr_e('Save Settings', 'show-support-ribbon'); ?>" />
						</div>
					</div>
					
					<div id="mm-panel-current" class="postbox">
						<h2><?php esc_html_e('Show Support', 'show-support-ribbon'); ?></h2>
						<div class="toggle">
							<?php require_once('support-panel.php'); ?>
						</div>
					</div>
					
				</div>
			</div>
			
			<div id="mm-credit-info">
				<a target="_blank" href="<?php echo $ssr_homeurl; ?>" title="<?php esc_attr_e('Plugin Homepage', 'show-support-ribbon'); ?>"><?php echo $ssr_plugin; ?></a> <?php esc_html_e('by', 'show-support-ribbon'); ?> 
				<a target="_blank" href="https://twitter.com/perishable" title="<?php esc_attr_e('Jeff Starr on Twitter', 'show-support-ribbon'); ?>">Jeff Starr</a> @ 
				<a target="_blank" href="https://monzillamedia.com/" title="<?php esc_attr_e('Obsessive Web Design &amp; Development', 'show-support-ribbon'); ?>">Monzilla Media</a>
			</div>
			
		</form>
	</div>
	
	<script type="text/javascript">
		jQuery(document).ready(function(){
			// toggle panels
			jQuery('.default-hidden').hide();
			jQuery('#mm-panel-toggle a').click(function(){
				jQuery('.toggle').slideToggle(300);
				return false;
			});
			jQuery('h2').click(function(){
				jQuery(this).next().slideToggle(300);
			});
			jQuery('#mm-panel-primary-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-panel-primary .toggle').slideToggle(300);
				return true;
			});
			jQuery('#mm-panel-secondary-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-panel-secondary .toggle').slideToggle(300);
				return true;
			});
			jQuery('#mm-panel-tertiary-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-panel-tertiary .toggle').slideToggle(300);
				return true;
			});
			// prevent accidents
			if(!jQuery("#mm_restore_defaults").is(":checked")){
				jQuery('#mm_restore_defaults').click(function(event){
					var r = confirm("<?php esc_html_e('Are you sure you want to restore all default options? (this action cannot be undone)', 'show-support-ribbon'); ?>");
					if (r == true){  
						jQuery("#mm_restore_defaults").attr('checked', true);
					} else {
						jQuery("#mm_restore_defaults").attr('checked', false);
					}
				});
			}
			// radio select toggle
			if(jQuery('form input[type=radio]:checked').val() == 'ssr_custom'){
				jQuery('.mm-custom-style').show();
			} else {
				jQuery('.mm-custom-style').hide();
			}
			jQuery('form input:radio').change(function(){
				if (jQuery(this).val() == 'ssr_custom') {
					jQuery('.mm-custom-style').slideDown('fast');
				} else {
					jQuery('.mm-custom-style').slideUp('fast');
				}
			});
		});
	</script>

<?php }
